// Licensed under the Apache License, Version 2.0 (the "License"); you may not
// use this file except in compliance with the License. You may obtain a copy of
// the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations under
// the License.

export default {
  RESET_DOC: 'RESET_DOC',
  DOC_LOADED: 'DOC_LOADED',
  SHOW_CLONE_DOC_MODAL: 'SHOW_CLONE_DOC_MODAL',
  HIDE_CLONE_DOC_MODAL: 'HIDE_CLONE_DOC_MODAL',
  SHOW_DELETE_DOC_CONFIRMATION_MODAL: 'SHOW_DELETE_DOC_CONFIRMATION_MODAL',
  HIDE_DELETE_DOC_CONFIRMATION_MODAL: 'HIDE_DELETE_DOC_CONFIRMATION_MODAL',
  SHOW_UPLOAD_MODAL: 'SHOW_UPLOAD_MODAL',
  HIDE_UPLOAD_MODAL: 'HIDE_UPLOAD_MODAL',
  RESET_UPLOAD_MODAL: 'RESET_UPLOAD_MODAL',
  SHOW_STRING_EDIT_MODAL: 'SHOW_STRING_EDIT_MODAL',
  HIDE_STRING_EDIT_MODAL: 'HIDE_STRING_EDIT_MODAL',
  FILE_UPLOAD_SUCCESS: 'FILE_UPLOAD_SUCCESS',
  FILE_UPLOAD_ERROR: 'FILE_UPLOAD_ERROR',
  START_FILE_UPLOAD: 'START_FILE_UPLOAD',
  SET_FILE_UPLOAD_PERCENTAGE: 'SET_FILE_UPLOAD_PERCENTAGE',
  SAVING_DOCUMENT: 'SAVING_DOCUMENT',
  SAVING_DOCUMENT_COMPLETED: 'SAVING_DOCUMENT_COMPLETED',
};
